==> gtkatlantic_0.2.6.tar.bz2: gtkatlantic_0.2.6/src/xmlparse.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright (C) 2002-2003 Rochet Sylvain
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <gtk/gtk.h>
#include <libxml/parser.h>

#define SERVER_XMLROOTELEMENT "monopd"
#define METASERVER_XMLROOTELEMENT "meta_atlantic"

void xmlparse_getgamelist_plugger(guint32 connectid);
void xmlparse_game_plugger(guint32 connectid);

void xmlparse_server(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_client(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_gameupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_message(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_display(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_configupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_cardupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_estategroupupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_deleteplayer(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);

void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);

void xmlparse_metaserver(guint32 connectid);

==> gtkatlantic-0.2.11.tar.bz2: gtkatlantic-0.2.11/src/xmlparse.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright (C) 2002-2003 Rochet Sylvain
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <gtk/gtk.h>
#include <libxml/parser.h>

#define SERVER_XMLROOTELEMENT "monopd"
#define METASERVER_XMLROOTELEMENT "meta_atlantic"

void xmlparse_getgamelist_plugger(guint32 connectid, guchar *buffer);
void xmlparse_game_plugger(guint32 connectid, guchar *buffer);

void xmlparse_server(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_client(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_gameupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_message(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_display(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_configupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_cardupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_estategroupupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
void xmlparse_deleteplayer(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);

void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);

void xmlparse_metaserver(guint32 connectid, guchar *buffer);
